 /*
	QuickTime Player Calling Functions - Windows Code
	Copyright © 2007-2008 Mariano Felice and Harry Whitfield

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA  02110-1301  USA
	
 	The QuickTime Player Calling Functions by Mariano Felice
 	were based on the cross-platform media player classes
 	created by Harry Whitfield.
 	
 	This version is a revision by Harry Whitfield of the
 	original functions by Mariano Felice.

	QuickTime Player Calling Functions - Windows Code - version b1
	7 February, 2008
	Copyright © 2007-2008 Mariano Felice and Harry Whitfield
	mailto:marianofelice@yahoo.com or mailto:g6auc@arrl.net 
*/

function QT(url)	// Constructor of QT object
{
	eprint('QT:url: "' + url + '"');
	if (url === undefined) { url = ""; }
	this.URL = url;
	this.player = COM.createObject("QuickTimePlayerLib.QuickTimePlayerApp.1");
	sleep(2500);
	this.movie  = this.player.Players.Item(1);
	this.QTControl = this.movie.QTControl;
	this.controls = this.QTControl.Movie;
	this.QTControl.AutoPlay = false;
	if (url !== "") { this.movie.OpenURL(url); }
	sleep(2500);
}

// Constants

QT.qtPaused		=  0;	// The current media item is paused or stopped.
QT.qtPlaying	=  1;	// The current media item is playing.

// Static Method

QT.formatTime = function (time)    // convert time in seconds to [hh:]mm:ss
{
    function twoDigits(n) { n = String(n); while (n.length < 2) { n = "0" + n; } return n; }    

    time = Math.floor(time);
    var secs = time % 60;
    time = Math.round((time - secs) / 60);
    var mins = time % 60;
    var hours = Math.round((time - mins) / 60); 
    var res = twoDigits(mins) + ':' + twoDigits(secs);
    if (hours !== 0) { res = String(hours) + ':' + res; }
    return res;
};

// Methods

QT.prototype.quit = function()
{
	this.controls.Stop();
	this.movie = this.QTControl = this.controls = null;
	this.player = null;
};

QT.prototype.getURL					= function()		{ return this.URL; };
QT.prototype.setURL      			= function(url) 	{ this.movie.OpenURL(url); this.URL = url; };
QT.prototype.versionInfo 			= function()	 	{ return this.QTControl.QuickTime.VersionAsString; };
QT.prototype.close       			= function()	 	{ this.QTControl.URL = ""; this.URL = ""; };
QT.prototype.playState   			= function()	 	{ return this.controls.Rate; };
QT.prototype.mediaDuration			= function()		{ return 0; };
QT.prototype.mediaDurationString	= function()		{ return "00:00"; };

QT.prototype.controlAvailable		= function(type)	{ return true; };
QT.prototype.play        			= function()	 	{ this.controls.Play(); };
QT.prototype.pause       			= function() 	 	{ this.controls.Pause(); };
QT.prototype.playPause   			= function() 	 	{ if (this.playState() == QT.qtPaused) { this.play(); } else { this.pause(); } };
QT.prototype.stop        			= function()	 	{ this.controls.Stop(); };
QT.prototype.fastForward 			= function() 	 	{ this.controls.GotoEnd(); };
QT.prototype.fastReverse 			= function() 	 	{ this.controls.Rewind(); };
QT.prototype.currentPosition       	= function() 		{ this.controls.timeScale = 1; return this.controls.Time; };
QT.prototype.setCurrentPosition    	= function(seconds) {  };
QT.prototype.currentPositionString 	= function() 		{ this.controls.timeScale = 1; return QT.formatTime(this.controls.Time); };
QT.prototype.getPlayerPosition 		= function() 		{ return this.player.currentPositionString(); };

QT.prototype.volume    	 			= function() 	 	{ return (this.controls.AudioVolume * 100).toFixed(); }; 
QT.prototype.setVolume   			= function(volume) 	{ this.controls.AudioVolume = volume/100; };
QT.prototype.autoStart	 			= function()	 	{ return this.QTControl.AutoPlay; };
QT.prototype.setAutoStart			= function(flag) 	{ this.QTControl.AutoPlay = flag; };
QT.prototype.mute	     			= function()    	{ return this.controls.AudioMute; };
QT.prototype.setMute     			= function(flag)   	{ this.controls.AudioMute = flag; };

QT.prototype.bitRate 	 			= function()    	{ return parseInt(this.controls.DataRate/1000, 10); };
QT.prototype.downloadProgress 		= function()   		{ return 100; };

QT.prototype.setMiniaturized  		= function(flag) 	{  };

/*
Example calls

var qtPlayer = new QT();                                              // construct QT player for use later
var qtPlayer = new QT("file:///Users/nhw/Movies/Ricky on Glass.mp4"); // construct QT player to play local file
var qtPlayer = new QT("http://proxitv12.speednet.at/radioktn");       // construct QT player to play remote file or stream

qtPlayer.quit();                       	// release the QT player - it is important to use this call when done with the player

qtPlayer.getURL();                  	// get the url of the movie or stream
qtPlayer.setURL(url);                  	// set or change the movie or stream
qtPlayer.versionInfo();                	// get the Windows Media Player or QuickTime Player version number
qtPlayer.close();                      	// close the current movie or stream
qtPlayer.playState();                  	// get the state of the player 0..1 (see list of constants)
qtPlayer.mediaDuration();              	// get the duration of the current item (in seconds)
qtPlayer.mediaDurationString();        	// get the duration of the current item (in [hh:]mm:ss)

qtPlayer.controlAvailable(type);		// does control "type" exist?
qtPlayer.play();                      	// pause the current movie or stream
qtPlayer.pause();                      	// pause the current movie or stream
qtPlayer.playPause();                  	// toggle between play and pause
qtPlayer.stop();                       	// stop the current movie or stream
qtPlayer.fastForward();                	// move to the end of the current movie
qtPlayer.fastReverse();                	// rewind to the beginning of the current movie
qtPlayer.currentPosition();            	// get playing time in seconds
qtPlayer.setCurrentPosition(secs);     	// set playing time in seconds
qtPlayer.currentPositionString();      	// get playing time in [hh:]mm:ss
qtPlayer.getPlayerPosition();          	// get playing time in [hh:]mm:ss

qtPlayer.volume();                     	// get the sound volume 0..100
qtPlayer.setVolume(volume);            	// set the sound volume 0..100
qtPlayer.autoStart();                  	// get the autoStart state (boolean)
qtPlayer.setAutoStart(flag);           	// set the autoStart state (boolean) - applies only to movies
qtPlayer.mute();                       	// get the muted state (boolean)
qtPlayer.setMute(flag);                	// set the muted state (boolean)

qtPlayer.bitRate ();                   	// get the data rate in kbps
qtPlayer.downloadProgress();           	// get download progress (percentage 0..100)

qtPlayer.setMiniaturized(flag)			// hide or show the QuickTime Player window.
*/
