 /*
	Cross-platform WMP Calling Functions - Windows Code
	Copyright © 2007-2008 Harry Whitfield
	
	CD Functions for Windows
	Copyright 2007 Michael Tughan

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA  02110-1301  USA
	
	Cross-platform WMP Calling Functions version 2.9.1
	10 February, 2008
	Copyright  2007-2008 Harry Whitfield
	mailto:g6auc@arrl.net
	
	Playlist Object and CD Functions
	27 May, 2007
	Copyright 2007 Michael Tughan
	mailto: michaelsprogramming@ca.inter.net
*/

function WMP(url)	// Constructor of WMP object
{
	if (!url) { eprint('WMP: url: "' + url + '"'); }
	try
	{
		this.player   = COM.createObject("WMPlayer.OCX");
		this.controls = this.player.controls;
		this.network  = this.player.network;
		this.settings = this.player.settings;
		this.settings.autoStart = false;
		this.URL = url;
		if (url) { this.player.URL = url; }
	}
	catch (e)
	{
		beep(); alert('WMP constructor: ' + e);
		this.player = this.controls = this.network = this.settings = null;
		return;
	}
}

WMP.prototype.quit = function()
{
	this.stop();
	this.controls = this.network = this.settings = null;
	this.player   = null;
};


// constants

WMP.wmppsUndefined     =  0;	// Windows Media Player is in an undefined state.
WMP.wmppsStopped       =  1;	// Playback of the current media item is stopped.
WMP.wmppsPaused        =  2;	// Playback of the current media item is paused. When a media item is paused, resuming playback begins from the same location.
WMP.wmppsPlaying       =  3;	// The current media item is playing.
WMP.wmppsScanForward   =  4;	// The current media item is fast forwarding.
WMP.wmppsScanReverse   =  5;	// The current media item is fast rewinding.
WMP.wmppsBuffering     =  6;	// The current media item is getting additional data from the server.
WMP.wmppsWaiting       =  7;	// Connection is established, but the server is not sending data. Waiting for session to begin.
WMP.wmppsMediaEnded    =  8;	// Media item has completed playback.
WMP.wmppsTransitioning =  9;	// Preparing new media item.
WMP.wmppsReady         = 10;	// Ready to begin playing.
WMP.wmppsReconnecting  = 11;	// Reconnecting to stream.


// via player object

WMP.prototype.getURL = function() { return this.URL; };
WMP.prototype.setURL        = function(url) {
	if (!url) { eprint('setURL: url: "' + url + '"'); }
	this.URL = url;
	if (url) { this.player.URL = url; }
};
WMP.prototype.versionInfo   = function()    { return this.player.versionInfo; };
WMP.prototype.close         = function()    { this.player.close(); };
WMP.prototype.playState     = function()    { return this.player.playState; };	// 0..11
WMP.prototype.mediaDuration = function ()   { return this.player.currentMedia.duration; };
WMP.prototype.mediaDurationString = function () { WMP.formatTime(this.mediaDuration()); };
WMP.prototype.getCDs        = function(sep) { 
	if (sep === undefined) { sep = "|"; }
	var cdroms = this.player.cdromCollection, cds = [];
	for (var i = 0; i < cdroms.Count; i += 1) {
		if (cdroms.item(i).playlist.Count !== 0) { cds[cds.length] = i + sep + cdroms.item(i).playlist.getItemInfo("Author") + " - " + cdroms.item(i).playlist.name; }
	}
	return cds;
};
WMP.prototype.getCD         = function(index){ 
	var cd = this.player.cdromCollection.item(index).playlist;
	var playlist = new Playlist(cd.getItemInfo("Author"), cd.name);
	for (var i = 0; i < cd.Count; i += 1) { playlist.addItem(cd.item(i).name, cd.item(i).SourceURL); }
	return playlist;
};


// via controls object

WMP.prototype.controlAvailable = function(type) { return true; };
WMP.prototype.play        = function() { if (this.controls.isAvailable('Play'))        { this.controls.play(); } };
WMP.prototype.pause       = function() { if (this.controls.isAvailable('Pause'))       { this.controls.pause(); } };
WMP.prototype.playPause   = function() { if (this.playState() == WMP.wmppsPlaying)     { this.pause(); } else { this.play(); } };
WMP.prototype.stop        = function() { if (this.controls.isAvailable('Stop'))        { this.controls.stop(); } };
WMP.prototype.fastForward = function() { if (this.controls.isAvailable('FastForward')) { this.controls.fastForward(); } };
WMP.prototype.fastReverse = function() { if (this.controls.isAvailable('FastReverse')) { this.controls.fastReverse(); } };
WMP.prototype.currentPosition       = function () { return this.controls.currentPosition; };
WMP.prototype.setCurrentPosition    = function (seconds) { this.controls.currentPosition = seconds; };
WMP.prototype.currentPositionString = function () { return this.controls.currentPositionString; };
WMP.prototype.getPlayerPosition     = function () { return this.controls.currentPositionString; };	// backward compatibility


// via settings object

WMP.prototype.volume       = function()       { return this.settings.volume; };
WMP.prototype.setVolume    = function(volume) { this.settings.volume = volume; };	// volume 0..100 ???
WMP.prototype.autoStart    = function()       { return this.settings.autoStart; };
WMP.prototype.setAutoStart = function(flag)   { this.settings.autoStart = flag; };
WMP.prototype.mute         = function()       { return this.settings.mute; };
WMP.prototype.setMute      = function(flag)   { this.settings.mute = flag; };

WMP.prototype.getStatus    = function()       {
												if(wmpPlayer.mute()) 								  { return"Muted"; } else
												if( wmpPlayer.playState() == WMP.wmppsBuffering ) 	  { return"Buffering..."; } else
												if ( wmpPlayer.playState() == WMP.wmppsWaiting )  	  { return"Waiting on Server..."; } else
												if ( wmpPlayer.playState() == WMP.wmppsReconnecting ) { return"Reconnecting to Media Stream..."; } else
												if ( wmpPlayer.playState() == WMP.wmppsStopped )	  { return"Stopped"; } else
												if ( wmpPlayer.playState() == WMP.wmppsPaused )		  { return"Paused"; } else
												if ( wmpPlayer.playState() == WMP.wmppsPlaying )	  { return"Playing"; } else
												if ( wmpPlayer.playState() == WMP.wmppsUndefined )	  { return"Media Player Idle"; } else
												if ( wmpPlayer.playState() == WMP.wmppsMediaEnded )	  { return"Media Ended"; } else
												if ( wmpPlayer.playState() == WMP.wmppsReady )		  { return"Media Player Ready"; } else {return"Wating..."; }
											  };

// via network object

WMP.prototype.bitRate          = function()   { return parseInt(this.network.bitRate/1000, 10); };	// converted to kbps
WMP.prototype.downloadProgress = function()   { return this.network.downloadProgress; };

WMP.prototype.setMiniaturized  = function(flag) { return; };

WMP.formatTime = function (time)    // convert time in seconds to [hh:]mm:ss
{
    function twoDigits(n) { n = String(n); while (n.length < 2) { n = "0" + n; } return n; }    

    time = Math.floor(time);
    var secs = time % 60;
    time = Math.round((time - secs) / 60);
    var mins = time % 60;
    var hours = Math.round((time - mins) / 60); 
    
    var res = twoDigits(mins) + ':' + twoDigits(secs);
    if (hours !== 0) { res = String(hours) + ':' + res; }
    return res;
};

